@@ -10,6 +10,7 @@
 
 #include <string.h>
 #include "utils.h"
+#include <Rversion.h>
 
 /* Workaround for performance bug: https://github.com/libgit2/libgit2/issues/5725 */
 #if AT_LEAST_LIBGIT2(0, 26)
@@ -80,11 +81,19 @@ static char* get_password(SEXP cb, const char *url, const char **username, int r
 static int get_key_files(SEXP cb, auth_key_data *out, int verbose){
   if(!Rf_isFunction(cb))
     Rf_error("cb must be a function");
-  int err;
+  int err = 0;
   SEXP call = PROTECT(Rf_lcons(cb, R_NilValue));
   SEXP res = PROTECT(verbose ? R_tryEval(call, R_GlobalEnv, &err) :
                        R_tryEvalSilent(call, R_GlobalEnv, &err));
+  if(res && Rf_inherits(res, "try-error")){
+    static char custom_callback_error[1000] = {0};
+    snprintf(custom_callback_error, 999, "SSH authentication failure: %s", CHAR(STRING_ELT(res, 0)));
+    giterr_set_str(GIT_ERROR_CALLBACK, custom_callback_error);
+    UNPROTECT(2);
+    return -1;
+  }
   if(err || !Rf_isString(res)){
+    giterr_set_str(GIT_ERROR_CALLBACK, "Failed to read local SSH key from callback function");
     UNPROTECT(2);
     return -1;
   }
@@ -170,7 +179,8 @@ static int auth_callback(git_cred **cred, const char *url, const char *username,
   auth_callback_data_t *cb_data = payload;
   const char * ssh_user = username ? username : "git";
   int verbose = cb_data->verbose;
-  char custom_callback_error[1000] = "Authentication failure";
+  giterr_clear();
+
 
 #if AT_LEAST_LIBGIT2(0, 20)
 
@@ -199,8 +209,6 @@ static int auth_callback(git_cred **cred, const char *url, const char *username,
                                key_data.key_path, key_data.pass_phrase)){
         print_if_verbose("Trying to authenticate '%s' using provided ssh-key...\n", ssh_user);
         return 0;
-      } else if(R_curErrorBuf()){
-        snprintf(custom_callback_error, 999, "SSH authentication failure: %s", R_curErrorBuf());
       }
     }
 
@@ -226,6 +234,7 @@ static int auth_callback(git_cred **cred, const char *url, const char *username,
       char *pass = get_password(cb_data->getcred, url, &username, cb_data->retries);
       if(!username || !pass){
         print_if_verbose("Credential lookup failed\n");
+        giterr_set_str(GIT_ERROR_CALLBACK, "HTTPS Authentication failure");
         goto failure;
       } else {
         return git_cred_userpass_plaintext_new(cred, username, pass);
@@ -234,7 +243,6 @@ static int auth_callback(git_cred **cred, const char *url, const char *username,
   }
   print_if_verbose("All authentication methods failed\n");
 failure:
-  giterr_set_str(GIT_ERROR_CALLBACK, custom_callback_error);
   return GIT_EAUTH;
 }
 
